"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Depot = void 0;
const cryptojs = __importStar(require("crypto-js"));
const Errors = __importStar(require("./Errors"));
class Depot {
    constructor() {
        this.setItem = (key, value) => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            if (this.depot.has(key))
                throw new Errors.KeyConflictError(key);
            try {
                JSON.stringify(value);
            }
            catch {
                throw new Errors.ValueMalformedError(value);
            }
            this.depot.set(key, value);
        };
        this.getItem = (key) => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            if (!this.depot.has(key))
                throw new Errors.KeyNotFoundError(key);
            return this.depot.get(key);
        };
        this.updateItem = (key, value) => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            if (!this.depot.has(key))
                throw new Errors.KeyNotFoundError(key);
            try {
                JSON.stringify(value);
            }
            catch {
                throw new Errors.ValueMalformedError(value);
            }
            this.depot.set(key, value);
        };
        this.removeItem = (key) => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            if (!this.depot.has(key))
                throw new Errors.KeyNotFoundError(key);
            this.depot.delete(key);
        };
        this.export = () => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            return Object.fromEntries(this.depot);
        };
        this.load = (data) => {
            this.depot = new Map(Object.entries(data));
        };
        this._serialize = (key) => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            const object = Object.fromEntries(this.depot);
            const string = JSON.stringify(object);
            if (key) {
                const encrypted = cryptojs.AES.encrypt(string, key).toString();
                return encrypted;
            }
            return string;
        };
        this._deserialize = (data, key) => {
            if (key)
                data = cryptojs.AES.decrypt(data, key).toString(cryptojs.enc.Utf8);
            const object = JSON.parse(data);
            this.depot = new Map(Object.entries(object));
        };
        this.clear = () => {
            if (!this.depot)
                throw new Errors.NullDepotError();
            this.depot.clear();
        };
        this.destory = () => {
            this.depot = null;
        };
        this.depot = new Map();
    }
}
exports.Depot = Depot;
//# sourceMappingURL=Depot.js.map