"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectReader = exports.JsonReader = exports.ChunkReader = void 0;
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
const zstd = __importStar(require("zstd.ts"));
const cryptojs = __importStar(require("crypto-js"));
const Errors = __importStar(require("./Errors"));
class Reader {
}
class ChunkReader extends Reader {
    constructor(basePath, chunkName) {
        super();
        this.getChunkFileName = (index) => {
            return path.join(this.basePath, `${this.chunkName}-${index}.cdu`);
        };
        this.readWithoutParse = () => {
            const chunks = [];
            let i = 0;
            while (fs.existsSync(this.getChunkFileName(i))) {
                const chunk = fs.readFileSync(this.getChunkFileName(i));
                chunks.push(chunk);
                i++;
            }
            if (i === 0)
                throw new Errors.ChunkDoesNotExistError(this.chunkName);
            const concated = Buffer.concat(chunks);
            const stringData = zstd
                .decompressSync({ input: concated })
                .toString("utf-8");
            return stringData;
        };
        this.readWithKey = (key) => {
            const data = cryptojs.AES.decrypt(this.readWithoutParse(), key).toString(cryptojs.enc.Utf8);
            return JSON.parse(data);
        };
        this.read = (key) => {
            if (key)
                return this.readWithKey(key);
            return JSON.parse(this.readWithoutParse());
        };
        this.basePath = basePath;
        this.chunkName = chunkName;
    }
}
exports.ChunkReader = ChunkReader;
class JsonReader extends Reader {
    constructor(filePath, encoding) {
        super();
        this.read = () => {
            const content = fs.readFileSync(this.filePath, this.encoding);
            return JSON.parse(content);
        };
        this.filePath = filePath;
        this.encoding = encoding || "utf8";
    }
}
exports.JsonReader = JsonReader;
class ObjectReader extends Reader {
    constructor(object) {
        super();
        this.read = () => {
            return JSON.parse(JSON.stringify(this.object));
        };
        this.object = object;
    }
}
exports.ObjectReader = ObjectReader;
//# sourceMappingURL=Reader.js.map